@@ -4,15 +4,11 @@ use warnings;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '0.18';
-
-#############################################################################
-#Library Modules															#
-#############################################################################
+$VERSION = '0.21';
 
 use base 'Test::CPAN::Meta::YAML';
 
-q( Currently Listening To: Paul Menel - "The Nurse" from 'Three Sides To Every Story');
+q( "Before software can be reusable it first has to be usable." - Ralph Johnson );
 
 __END__
 
@@ -20,7 +16,7 @@ __END__
 
 =head1 NAME
 
-Test::YAML::Meta - Validation of the META.yml file in a distribution.
+Test::YAML::Meta - Validate your CPAN META.yml files.
 
 =head1 DESCRIPTION
 
@@ -31,6 +27,11 @@ that distribution for further details.
 
 A test module to validate a META.yml file.
 
+=head1 WARNING
+
+This distribution will be retired at the end of 2015. Please replace your 
+references to this module with L<Test::CPAN::Meta::YAML>.
+
 =head1 BUGS, PATCHES & FIXES
 
 There are no known bugs at the time of this release. However, if you spot a
@@ -40,21 +41,13 @@ RT system (http://rt.cpan.org/Public/Dist/Display.html?Name=Test-YAML-Meta).
 However, it would help greatly if you are able to pinpoint problems or even
 supply a patch.
 
-Fixes are dependant upon their severity and my availablity. Should a fix not
+Fixes are dependent upon their severity and my availability. Should a fix not
 be forthcoming, please feel free to (politely) remind me.
 
 =head1 SEE ALSO
 
 L<Test::CPAN::Meta::YAML>.
 
-=head1 DSLIP
-
-  b - Beta testing
-  d - Developer
-  p - Perl-only
-  O - Object oriented
-  p - Standard-Perl: user may choose between GPL and Artistic
-
 =head1 AUTHOR
 
 Barbie, <barbie@cpan.org>
@@ -62,9 +55,9 @@ for Miss Barbell Productions, L<http://www.missbarbell.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-  Copyright (C) 2009-2011 Barbie for Miss Barbell Productions
+  Copyright (C) 2009-2015 Barbie for Miss Barbell Productions
 
-  This module is free software; you can redistribute it and/or
+  This distribution is free software; you can redistribute it and/or
   modify it under the Artistic Licence v2.
 
 =cut
